==> moodle-1.5-mysql.tgz: moodle/lang/sk/message.php <==
<?PHP // $Id$ 
      // message.php - created with Moodle 1.6 development (2005052400)


$string['addcontact'] = 'Prida kontakt';
$string['addsomecontacts'] = 'Pre poslanie sprvy niekomu, alebo pre pridanie odkazu naho na tto strnku poui <a href=\"$a\">zloku vyhadvanie</a>.';
$string['addsomecontactsincoming'] = 'Tieto sprvy s od ud ktorch nem v zozname kontaktov. Pokia si ich chce prida medzi svoje kontakty, klikni na ikonu \"Prida kontakt\" za ich menom.';
$string['ago'] = '$a predtm';
$string['allmine'] = 'Vetky sprvy pre ma alebo odo ma';
$string['allstudents'] = 'Vetky sprvy medzi tudentmi v kurze';
$string['allusers'] = 'Vetky sprvy od vetkch uvateov';
$string['backupmessageshelp'] = 'Pokia je toto zapnut, sprva bude zahrnut do automatickho zlohovania web strnok.';
$string['beepnewmessage'] = 'Ppni ke prde nov sprva (pre prehratie zvuku me potrebova zsuvn modul do prehliadaa, ako naprklad Quicktime)';
$string['blockcontact'] = 'Zablokova kontakt';
$string['blockedmessages'] = '$a sprva(y) pre/od blokovanch uvateov';
$string['blocknoncontacts'] = 'Zablokuj vetky nov sprvy od ud ktor nie s v mojom zozname kontaktov';
$string['contactlistempty'] = 'Tvoj zoznam kontaktov je prve przdny';
$string['contacts'] = 'Kontakty';
$string['context'] = 'obsah';
$string['deletemessagesdays'] = 'Poet dn po ktorch bud star sprvy automaticky vymazan';
$string['discussion'] = 'Diskusie';
$string['emailmessages'] = 'Pokia nie som prihlsen, posliela mi sprvy e-mailom';
$string['emailtagline'] = 'Tento e-mail je kpia sprvy ktor ti bola poslan na \"$a\"';
$string['emptysearchstring'] = 'Mus nieo hada';
$string['formorethan'] = 'Pre viac ako';
$string['includeblockedusers'] = 'Zahrn blokovanch pouvateov';
$string['incomingcontacts'] = 'Prichdzajce kontakty ($a)';
$string['keywords'] = 'Kov slov';
$string['keywordssearchresults'] = 'Vsledok hadania: $a njdench sprv';
$string['maxmessages'] = 'Maximlny poet sprv ktor bud zobrazovan v histrii diskusi';
$string['message'] = 'Sprva';
$string['messagehistory'] = 'Histria sprv';
$string['messages'] = 'Sprvy';
$string['messaging'] = 'Posielanie sprv';
$string['mycontacts'] = 'Moje kontakty';
$string['newsearch'] = 'Nov hadanie';
$string['nomessages'] = 'Neakaj iadne sprvy';
$string['nomessagesfound'] = 'Neboli njden iadne sprvy';
$string['nosearchresults'] = 'Nepodarilo sa njs iadne vsledky';
$string['offline'] = 'Nepripojen';
$string['offlinecontacts'] = 'Nepripojen uvatelia ($a)';
$string['online'] = 'Pripojen';
$string['onlinecontacts'] = 'Pripojen uvatelia ($a)';
$string['onlyfromme'] = 'Iba sprvy odo ma';
$string['onlymycourses'] = 'Iba v mojich kurzoch';
$string['onlytome'] = 'Iba sprvy pre ma';
$string['pagerefreshes'] = 'Tto strnka sa obnov automaticky kadch $a seknd';
$string['readmessages'] = '$a ta sprvy';
$string['removecontact'] = 'Odstrni kontakt';
$string['savemysettings'] = 'Ulo moje nastavenia';
$string['search'] = 'Hadaj';
$string['searchforperson'] = 'Hadaj osobu';
$string['searchmessages'] = 'Hadaj sprvu';
$string['sendmessage'] = 'Poli sprvu';
$string['sendmessageto'] = 'Poli sprvu pre $a';
$string['settings'] = 'Nastavenia';
$string['settingssaved'] = 'Tvoje nastavenia boli uloen';
$string['showmessagewindow'] = 'Automaticky zobraz okno sprv ke dostanem nov sprvu (tvoj prehliada je potrebn nastavi tak aby neblokoval vyskakujce okn na tejto strnke)';
$string['strftimedaydatetime'] = '%%A, %%d %%B %%Y, %%I:%%M %%p';
$string['timenosee'] = 'Poet mint odkedy som bol naposledy pripojen';
$string['timesent'] = 'as poslania';
$string['unblockcontact'] = 'Odblokuj kontakt';
$string['unreadmessages'] = '$a netanch sprv';
$string['userisblockingyou'] = 'Tento uvate m nastaven blokovanie sprv od teba';
$string['userisblockingyounoncontact'] = 'Tento uvate prijma sprvy iba od ud, ktorch m zapsanch vo svojom zozname kontaktov a ty sa v om nenachdza. ';
$string['userssearchresults'] = 'Vsledok hadania: $a njdench uvateov';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/sk/message.php <==
<?PHP // $Id$ 
      // message.php - created with Moodle 1.6 development (2005052400)


$string['addcontact'] = 'Prida kontakt';
$string['addsomecontacts'] = 'Pre poslanie sprvy niekomu, alebo pre pridanie odkazu naho na tto strnku poui <a href=\"$a\">zloku vyhadvanie</a>.';
$string['addsomecontactsincoming'] = 'Tieto sprvy s od ud ktorch nem v zozname kontaktov. Pokia si ich chce prida medzi svoje kontakty, klikni na ikonu \"Prida kontakt\" za ich menom.';
$string['ago'] = '$a predtm';
$string['allmine'] = 'Vetky sprvy pre ma alebo odo ma';
$string['allstudents'] = 'Vetky sprvy medzi tudentmi v kurze';
$string['allusers'] = 'Vetky sprvy od vetkch pouvateov';
$string['backupmessageshelp'] = 'Pokia je toto zapnut, sprva bude zahrnut do automatickho zlohovania web strnok.';
$string['beepnewmessage'] = 'Ppni ke prde nov sprva (pre prehratie zvuku me potrebova zsuvn modul do prehliadaa, ako naprklad Quicktime)';
$string['blockcontact'] = 'Zablokova kontakt';
$string['blockedmessages'] = '$a sprva(y) pre/od blokovanch pouvateov';
$string['blocknoncontacts'] = 'Zablokuj vetky nov sprvy od ud ktor nie s v mojom zozname kontaktov';
$string['contactlistempty'] = 'Tvoj zoznam kontaktov je prve przdny';
$string['contacts'] = 'Kontakty';
$string['context'] = 'obsah';
$string['deletemessagesdays'] = 'Poet dn po ktorch bud star sprvy automaticky vymazan';
$string['discussion'] = 'Diskusie';
$string['emailmessages'] = 'Pokia nie som prihlsen, posliela mi sprvy e-mailom';
$string['emailtagline'] = 'Tento e-mail je kpia sprvy ktor ti bola poslan na \"$a\"';
$string['emptysearchstring'] = 'Mus nieo hada';
$string['formorethan'] = 'Pre viac ako';
$string['includeblockedusers'] = 'Zahrn blokovanch pouvateov';
$string['incomingcontacts'] = 'Prichdzajce kontakty ($a)';
$string['keywords'] = 'Kov slov';
$string['keywordssearchresults'] = 'Vsledok hadania: $a njdench sprv';
$string['maxmessages'] = 'Maximlny poet sprv ktor bud zobrazovan v histrii diskusi';
$string['message'] = 'Sprva';
$string['messagehistory'] = 'Histria sprv';
$string['messages'] = 'Sprvy';
$string['messaging'] = 'Posielanie sprv';
$string['mycontacts'] = 'Moje kontakty';
$string['newsearch'] = 'Nov hadanie';
$string['nomessages'] = 'Neakaj iadne sprvy';
$string['nomessagesfound'] = 'Neboli njden iadne sprvy';
$string['nosearchresults'] = 'Nepodarilo sa njs iadne vsledky';
$string['offline'] = 'Nepripojen';
$string['offlinecontacts'] = 'Nepripojen pouvatelia ($a)';
$string['online'] = 'Pripojen';
$string['onlinecontacts'] = 'Pripojen pouvatelia ($a)';
$string['onlyfromme'] = 'Iba sprvy odo ma';
$string['onlymycourses'] = 'Iba v mojich kurzoch';
$string['onlytome'] = 'Iba sprvy pre ma';
$string['pagerefreshes'] = 'Tto strnka sa obnov automaticky kadch $a seknd';
$string['readmessages'] = '$a ta sprvy';
$string['removecontact'] = 'Odstrni kontakt';
$string['savemysettings'] = 'Ulo moje nastavenia';
$string['search'] = 'Hadaj';
$string['searchforperson'] = 'Hadaj osobu';
$string['searchmessages'] = 'Hadaj sprvu';
$string['sendmessage'] = 'Poli sprvu';
$string['sendmessageto'] = 'Poli sprvu pre $a';
$string['settings'] = 'Nastavenia';
$string['settingssaved'] = 'Tvoje nastavenia boli uloen';
$string['showmessagewindow'] = 'Automaticky zobraz okno sprv ke dostanem nov sprvu (tvoj prehliada je potrebn nastavi tak aby neblokoval vyskakujce okn na tejto strnke)';
$string['strftimedaydatetime'] = '%%A, %%d %%B %%Y, %%I:%%M %%p';
$string['timenosee'] = 'Poet mint odkedy som bol naposledy pripojen';
$string['timesent'] = 'as poslania';
$string['unblockcontact'] = 'Odblokuj kontakt';
$string['unreadmessages'] = '$a netanch sprv';
$string['userisblockingyou'] = 'Tento pouvate m nastaven blokovanie sprv od teba';
$string['userisblockingyounoncontact'] = 'Tento pouvate prijma sprvy iba od ud, ktorch m zapsanch vo svojom zozname kontaktov a ty sa v om nenachdza. ';
$string['userssearchresults'] = 'Vsledok hadania: $a njdench pouvateov';

?>
